@@ -23,11 +23,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
+import aws_cdk.core
+
 
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-datapipeline.CfnPipeline"):
@@ -38,7 +37,7 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
     cloudformationResource:
     :cloudformationResource:: AWS::DataPipeline::Pipeline
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]], activate: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, description: typing.Optional[str]=None, parameter_values: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]]=None, pipeline_objects: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]]=None, pipeline_tags: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]], activate: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, description: typing.Optional[str]=None, parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]=None, pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]=None, pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]=None) -> None:
         """Create a new ``AWS::DataPipeline::Pipeline``.
 
         :param scope: - scope in which this resource is defined.
@@ -114,7 +113,7 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "name")
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         jsii.set(self, "name", value)
 
     @builtins.property
@@ -128,12 +127,12 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "parameterObjects")
 
     @parameter_objects.setter
-    def parameter_objects(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]]):
+    def parameter_objects(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]]) -> None:
         jsii.set(self, "parameterObjects", value)
 
     @builtins.property
     @jsii.member(jsii_name="activate")
-    def activate(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def activate(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
         see
@@ -142,7 +141,7 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "activate")
 
     @activate.setter
-    def activate(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def activate(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "activate", value)
 
     @builtins.property
@@ -156,12 +155,12 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
     @jsii.member(jsii_name="parameterValues")
-    def parameter_values(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]]:
+    def parameter_values(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
         see
@@ -170,12 +169,12 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "parameterValues")
 
     @parameter_values.setter
-    def parameter_values(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]]):
+    def parameter_values(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]) -> None:
         jsii.set(self, "parameterValues", value)
 
     @builtins.property
     @jsii.member(jsii_name="pipelineObjects")
-    def pipeline_objects(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]]:
+    def pipeline_objects(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
         see
@@ -184,12 +183,12 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "pipelineObjects")
 
     @pipeline_objects.setter
-    def pipeline_objects(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]]):
+    def pipeline_objects(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]) -> None:
         jsii.set(self, "pipelineObjects", value)
 
     @builtins.property
     @jsii.member(jsii_name="pipelineTags")
-    def pipeline_tags(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]]:
+    def pipeline_tags(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
         see
@@ -198,7 +197,7 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "pipelineTags")
 
     @pipeline_tags.setter
-    def pipeline_tags(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]]):
+    def pipeline_tags(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]) -> None:
         jsii.set(self, "pipelineTags", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-datapipeline.CfnPipeline.FieldProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'ref_value': 'refValue', 'string_value': 'stringValue'})
@@ -484,7 +483,7 @@ class CfnPipeline(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-datapipeline.CfnPipelineProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'parameter_objects': 'parameterObjects', 'activate': 'activate', 'description': 'description', 'parameter_values': 'parameterValues', 'pipeline_objects': 'pipelineObjects', 'pipeline_tags': 'pipelineTags'})
 class CfnPipelineProps():
-    def __init__(self, *, name: str, parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]], activate: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, description: typing.Optional[str]=None, parameter_values: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]]=None, pipeline_objects: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]]=None, pipeline_tags: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]]=None) -> None:
+    def __init__(self, *, name: str, parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]], activate: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, description: typing.Optional[str]=None, parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]=None, pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]=None, pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]=None) -> None:
         """Properties for defining a ``AWS::DataPipeline::Pipeline``.
 
         :param name: ``AWS::DataPipeline::Pipeline.Name``.
@@ -527,7 +526,7 @@ class CfnPipelineProps():
         return self._values.get('parameter_objects')
 
     @builtins.property
-    def activate(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def activate(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DataPipeline::Pipeline.Activate``.
 
         see
@@ -545,7 +544,7 @@ class CfnPipelineProps():
         return self._values.get('description')
 
     @builtins.property
-    def parameter_values(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]]:
+    def parameter_values(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
         see
@@ -554,7 +553,7 @@ class CfnPipelineProps():
         return self._values.get('parameter_values')
 
     @builtins.property
-    def pipeline_objects(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]]:
+    def pipeline_objects(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
         see
@@ -563,7 +562,7 @@ class CfnPipelineProps():
         return self._values.get('pipeline_objects')
 
     @builtins.property
-    def pipeline_tags(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]]:
+    def pipeline_tags(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
         see
